@@ -8,13 +8,13 @@ $ python3 scripts/create_baseline_stubs.py <project on PyPI>
 Run with -h for more help.
 """
 
+from __future__ import annotations
+
 import argparse
 import os
 import re
-import shutil
 import subprocess
 import sys
-from typing import Optional, Tuple
 
 if sys.version_info >= (3, 8):
     from importlib.metadata import distribution
@@ -22,7 +22,7 @@ if sys.version_info >= (3, 8):
 PYRIGHT_CONFIG = "pyrightconfig.stricter.json"
 
 
-def search_pip_freeze_output(project: str, output: str) -> Optional[Tuple[str, str]]:
+def search_pip_freeze_output(project: str, output: str) -> tuple[str, str] | None:
     # Look for lines such as "typed-ast==1.4.2".  '-' matches '_' and
     # '_' matches '-' in project name, so that "typed_ast" matches
     # "typed-ast", and vice versa.
@@ -33,7 +33,7 @@ def search_pip_freeze_output(project: str, output: str) -> Optional[Tuple[str, s
     return m.group(1), m.group(2)
 
 
-def get_installed_package_info(project: str) -> Optional[Tuple[str, str]]:
+def get_installed_package_info(project: str) -> tuple[str, str] | None:
     """Find package information from pip freeze output.
 
     Match project name somewhat fuzzily (case sensitive; '-' matches '_', and
@@ -45,24 +45,9 @@ def get_installed_package_info(project: str) -> Optional[Tuple[str, str]]:
     return search_pip_freeze_output(project, r.stdout)
 
 
-def run_stubgen(package: str) -> None:
-    print(f"Running stubgen: stubgen -p {package}")
-    subprocess.run(["stubgen", "-p", package], check=True)
-
-
-def copy_stubs(src_base_dir: str, package: str, stub_dir: str) -> None:
-    """Copy generated stubs to the target directory under stub_dir/."""
-    print(f"Copying stubs to {stub_dir}")
-    if not os.path.isdir(stub_dir):
-        os.mkdir(stub_dir)
-    src_dir = os.path.join(src_base_dir, package)
-    if os.path.isdir(src_dir):
-        shutil.copytree(src_dir, os.path.join(stub_dir, package))
-    else:
-        src_file = os.path.join("out", package + ".pyi")
-        if not os.path.isfile(src_file):
-            sys.exit("Error: Cannot find generated stubs")
-        shutil.copy(src_file, stub_dir)
+def run_stubgen(package: str, output: str) -> None:
+    print(f"Running stubgen: stubgen -o {output} -p {package}")
+    subprocess.run(["stubgen", "-o", output, "-p", package], check=True)
 
 
 def run_black(stub_dir: str) -> None:
@@ -85,7 +70,14 @@ def create_metadata(stub_dir: str, version: str) -> None:
     assert not os.path.exists(fnam)
     print(f"Writing {fnam}")
     with open(fnam, "w") as f:
-        f.write(f'version = "{version}.*"\n')
+        f.write(
+            f"""\
+version = "{version}.*"
+
+[tool.stubtest]
+ignore_missing_stub = false
+"""
+        )
 
 
 def add_pyright_exclusion(stub_dir: str) -> None:
@@ -98,7 +90,8 @@ def add_pyright_exclusion(stub_dir: str) -> None:
     assert i < len(lines), f"Error parsing {PYRIGHT_CONFIG}"
     while not lines[i].strip().startswith("]"):
         i += 1
-    line_to_add = f'        "{stub_dir}",'
+    # Must use forward slash in the .json file
+    line_to_add = f'        "{stub_dir}",'.replace("\\", "/")
     initial = i - 1
     while lines[i].lower() > line_to_add.lower():
         i -= 1
@@ -139,9 +132,11 @@ def main() -> None:
         # The importlib.metadata module is used for projects whose name is different
         # from the runtime Python package name (example: PyYAML/yaml)
         if sys.version_info >= (3, 8):
-            packages = [name for name in distribution(project).read_text("top_level.txt").split() if not name.startswith("_")]
-            if len(packages) == 1:
-                package = packages[0]
+            dist = distribution(project).read_text("top_level.txt")
+            if dist is not None:
+                packages = [name for name in dist.split() if not name.startswith("_")]
+                if len(packages) == 1:
+                    package = packages[0]
         print(f'Using detected package "{package}" for project "{project}"', file=sys.stderr)
         print("Suggestion: Try again with --package argument if that's not what you wanted", file=sys.stderr)
 
@@ -161,10 +156,7 @@ def main() -> None:
     if os.path.exists(stub_dir):
         sys.exit(f"Error: {stub_dir} already exists (delete it first)")
 
-    run_stubgen(package)
-
-    # Stubs were generated under out/. Copy them to stubs/.
-    copy_stubs("out", package, stub_dir)
+    run_stubgen(package, stub_dir)
 
     run_isort(stub_dir)
     run_black(stub_dir)
